latest_firmware

Function latest_firmware 

pub fn latest_firmware(model: DongleModel) -> Result<Option<FirmwareRelease>>
The latest firmware release published for model, or None if there are no published releases for it (yet).