pub struct UsbmuxdGuard { /* private fields */ }Expand description
RAII guard that starts the embedded usbmuxd server and tears it down on drop.
Implementations
Sourceimpl UsbmuxdGuard
impl UsbmuxdGuard
Sourcepub fn start(progress: ProgressFn<'_>) -> Result<Self>
pub fn start(progress: ProgressFn<'_>) -> Result<Self>
Start the embedded usbmuxd server and point libusbmuxd at it.